@@ -2,7 +2,7 @@
 A TiddlyWeb plugin providing a multi-user TiddlyWiki environment.
 """
 
-__version__ = '0.61.1'
+__version__ = '0.62.0'
 
 
 def friendlywiki(environ, start_response):
@@ -18,7 +18,7 @@ def friendlywiki(environ, start_response):
 def init(config):
     # These imports must be in init otherwise getting
     # the version number causes cyclic imports to happen.
-    import tiddlywebplugins.instancer
+    import tiddlywebplugins.imaker
     import tiddlywebplugins.status
     import tiddlywebplugins.atom
     import tiddlywebplugins.differ
@@ -28,7 +28,7 @@ def init(config):
     from tiddlywebwiki.config import config as twwconfig
 
     merge_config(config, twwconfig)
-    tiddlywebplugins.instancer.init(config)
+    tiddlywebplugins.imaker.init(config)
     tiddlywebplugins.status.init(config)
     tiddlywebplugins.atom.init(config)
     tiddlywebplugins.differ.init(config)
