@@ -2,22 +2,17 @@
 structure and contents of a default TiddlyWebWiki instance
 """
 
-from tiddlywebplugins.instancer.util import get_tiddler_locations
-
-from tiddlywebplugins.console.instance import (store_contents,
+from tiddlywebplugins.console.instance import (
     store_structure as console_store_structure)
 
-
 instance_config = {
     'system_plugins': ['tiddlywebwiki'],
     'twanager_plugins': ['tiddlywebwiki']
 }
 
-store_contents = get_tiddler_locations(store_contents,
-    'tiddlywebplugins.console')
-store_contents['system'] = [
-    'src/tiddlywebwiki.recipe'
-]
+store_contents = {
+        'system': ['src/tiddlywebwiki.recipe']
+}
 
 store_structure = {
     'bags': {
